% this class file is derived from the official FAU letter template at
% https://www.intern.fau.de/kommunikation-marketing-und-corporate-identity/vorlagen/briefvorlagen/

% instead of directly taking scrlttr2.cls, we use scrartcl.cls, since that gives us
% sections. We just have to load scrletter.sty later. 
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{faubrief}
\LoadClass[%
  version=first % Stabilitaet bei Aenderungen von 'scrlttr2'
]{scrartcl}

%%%%%%%%%%%%%%%%%%%%%% Pakete %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\RequirePackage{scrletter} % for the letter functionality
\RequirePackage[T1]{fontenc} % Umbrueche bei deutschen Umlauten, Schriftsatzerweiterung
\RequirePackage[utf8]{inputenc} % Direkte Eingabe deutscher Umlaute
\RequirePackage{graphicx}
\RequirePackage{paralist}
\RequirePackage{xspace}
\RequirePackage{url}
\RequirePackage{eurosym}\def\texteuro{\euro\xspace}
\RequirePackage[ngerman, num]{isodate} % Datum im Format tt.mm.jjjj
\monthyearsepgerman{\,}{\,} % kein Leerzeichen zwischen Monat und Jahr
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%% Fakultaet %%%%%%%%%%%%%%%%%%%%%%%%%%%%
% An dieser Stelle werden fakultaetsspezifische Einstellungen
% getroffen.
\newcommand{\coloredlogo}{true}
%
% Welcher Fakultaet gehoere ich an?
\newcommand*{\fromdepartment}{tech}
%
% Moegliche Werte sind:
%   TAG            FAKULTAET
% ------------------------------------------------------------
% fau        FAU allgemein
% med        Medizinische Fakultaet
% nat        Naturwissenschaftliche Fakultaet
% philtheo   Philosophische Fakultaet und Fachbereich Theologie
% recht      Fachbereich Rechtswissenschaft
% rechtwirt  Rechts- und Wirtschaftswissenschaftliche Fakultaet
% sobe       School of Business, Economics and Society
% tech       Technische Fakultaet
% wiso       Fachbereich Wirtschafts- und Sozialwissenschaften
% template	 Template Logo eines abstrakten Fachbereichs zu Testzwecken
% ------------------------------------------------------------
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%% FAU-Design %%%%%%%%%%%%%%%%%%%%%%%%%%%
\LoadLetterOption{faudesign} % Laden des FAU-Stylefiles
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%% Absender %%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Ruecksendeadresse des Absenders
\setkomavar{backaddress}{Universit\"at Erlangen-N\"urnberg $\cdot$ Postfach 3520 $\cdot$ 91023 Erlangen}

%%%%%%%%%%%%%%%%%%%%%% Datum %%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Datum, 'faudate' ersetzt 'date'
% \today generiert das aktuelle Datum
\setkomavar{faudate}{\today}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Benoetige ich ein Lehrstuhl-Logo?
% Wenn ja, soll es im Kopf erscheinen?
%\setkomavar{departmentlogohead}{\includegraphics[height=25mm,width=45mm]{art/partnerlogo}}
% Oder im Fuss? -- In diesem Fall kann kein Partnerlogo verwandt werden!
%\setkomavar{departmentlogofoot}{\vspace{-0.8cm}\includegraphics[height=25mm,width=45mm]{art/partnerlogo}}
%
% Sollte das Alignment aufgrund weisser Ecken des Logos nicht passen
% so kann manuell mittels \vspace, \hspace nachjustiert werden.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Für den Briefinhalt müssen noch verschiedene Optionen gesetzt werden, typischerweise durch
% \LoadLetterOption{<name>} % lädt <absender>.lco (Absender)
% \LoadLetterOption{<orga>}  % lädt <orga>.lco (Organisationseinheit. )

% Die folgenden geben die Leerstellen
% Funktion des Absenders (% Wenn kein Lehrstuhl angegeben wird)
\setkomavar{fromfunction}{Professur für XXX}
% Lehrstuhl des Absenders
\setkomavar{fromdepartment}{Department XXX}
% Name des Absenders
\setkomavar{fromname}{Prof. Dr. XXX}
% Signatur des Absenders, falls abweichend von Name des Absenders
\setkomavar{signature}{XXX} 
% Strasse des Absenders
\setkomavar{fromstreet}{Martensstr. 3}
% Stadt des Absenders
\setkomavar{fromcity}{91054 Erlangen} 
% Telefonnummer des Absenders
\setkomavar{fromphone}{Telefon +49 XXX} 
% Faksimile des Absenders
\setkomavar{fromfax}{Fax +49 XXX} 
% Email des Absenders
\setkomavar{fromemail}{XXX.XXX@fau.de}
% Internetpraesenz des Absenders 
\setkomavar{fromurl}{https://}
% Aktenzeichen des Empfaengers
\setkomavar{yourref}{Ihr Zeichen }
% Bezugnehmend auf Nachricht des Empfaengers
\setkomavar{yourmessage}{Ihre Nachricht vom }
% Aktenzeichen des Absenders
\setkomavar{myref}{Unser Zeichen }
% Ort des Absenders
\setkomavar{place}{Erlangen}

%%%%%%%%%%%%%%%%%%%%%% Signature %%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\signaturepicture#1{\def\jcl@sigpic{#1}}
\def\sign#1{\strut\closing{#1\strut\\[.2cm]\includegraphics[width=6cm]{\jcl@sigpic}\strut\\[-1.2cm]}}



